Reland "Return parameters of event as well as event code."

The CL was previously reviewed at ag/842911.

> The CL makes MtpDevice#reapEvent return event parameters as well as
> event code.
>
> BUG=26480986

Change-Id: Ie750a58248068cd0e804f20b57e7e86eef19d315
diff --git a/media/mtp/MtpDevice.h b/media/mtp/MtpDevice.h
index 60f08ba..edc608f 100644
--- a/media/mtp/MtpDevice.h
+++ b/media/mtp/MtpDevice.h
@@ -124,8 +124,9 @@
     int                     submitEventRequest();
     // Waits for MTP event from the device and returns MTP event code. It blocks the current thread
     // until it receives an event from the device. |handle| should be a request handle returned
-    // by |submitEventRequest|. Returns 0 for cancellations. Returns -1 for errors.
-    int                     reapEventRequest(int handle);
+    // by |submitEventRequest|. The function writes event parameters to |parameters|. Returns 0 for
+    // cancellations. Returns -1 for errors.
+    int                     reapEventRequest(int handle, uint32_t (*parameters)[3]);
     // Cancels an event request. |handle| should be request handle returned by
     // |submitEventRequest|. If there is a thread blocked by |reapEventRequest| with the same
     // |handle|, the thread will resume.